@@ -1,6 +1,6 @@
 /***********************************************************************
  *
- * Copyright (C) 2009, 2012, 2013, 2014, 2015, 2016, 2017, 2018 Graeme Gott <graeme@gottcode.org>
+ * Copyright (C) 2009, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019 Graeme Gott <graeme@gottcode.org>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -138,7 +138,7 @@ Window::Window() {
 	connect(m_board, &Board::loading, m_clock, &Clock::setLoading);
 
 	QHBoxLayout* overlay_layout = new QHBoxLayout(overlay);
-	overlay_layout->setMargin(0);
+	overlay_layout->setContentsMargins(0, 0, 0, 0);
 	overlay_layout->setSpacing(0);
 	overlay_layout->addSpacing(10);
 	overlay_layout->addWidget(m_definitions_button);
@@ -150,7 +150,7 @@ Window::Window() {
 
 	// Lay out board
 	QGridLayout* layout = new QGridLayout(contents);
-	layout->setMargin(0);
+	layout->setContentsMargins(0, 0, 0, 0);
 	layout->setSpacing(0);
 	layout->addWidget(view, 0, 0);
 	layout->addWidget(m_success, 0, 0, Qt::AlignCenter);
@@ -262,7 +262,7 @@ void Window::about() {
 	QMessageBox::about(this, tr("About"), QString("<p><center><big><b>%1 %2</b></big><br/>%3<br/><small>%4<br/>%5</small></center></p><p><center>%6</center></p>")
 		.arg(tr("Connectagram"), QCoreApplication::applicationVersion(),
 			tr("A word unscrambling game"),
-			tr("Copyright &copy; 2009-%1 by Graeme Gott").arg("2018"),
+			tr("Copyright &copy; 2009-%1 by Graeme Gott").arg("2019"),
 			tr("Released under the <a href=\"http://www.gnu.org/licenses/gpl.html\">GPL 3</a> license"),
 			tr("Definitions are from <a href=\"http://wiktionary.org/\">Wiktionary</a>"))
 	);
